==> streamtuner-0.99.tar.gz: streamtuner-0.99/src/streamtuner/st-version.c <==
/*
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <glib.h>
#include "st-version-api.h"

/*** constant definitions ****************************************************/

const unsigned int st_major_version = ST_MAJOR_VERSION;
const unsigned int st_minor_version = ST_MINOR_VERSION;
const unsigned int st_micro_version = ST_MICRO_VERSION;

const unsigned int st_api_major_version = ST_API_MAJOR_VERSION;
const unsigned int st_api_minor_version = ST_API_MINOR_VERSION;

/*** API implementation ******************************************************/

gboolean
st_check_api_version (unsigned int required_major_version,
		      unsigned int minimum_minor_version)
{
  return st_api_major_version == required_major_version
    && st_api_minor_version >= minimum_minor_version;
}

==> streamtuner-0.99.99.tar.gz: streamtuner-0.99.99/src/streamtuner/st-version.c <==
/*
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <glib.h>
#include "st-version-api.h"

/*** constant definitions ****************************************************/

const unsigned int st_major_version = ST_MAJOR_VERSION;
const unsigned int st_minor_version = ST_MINOR_VERSION;
const unsigned int st_micro_version = ST_MICRO_VERSION;

const unsigned int st_api_major_version = ST_API_MAJOR_VERSION;
const unsigned int st_api_minor_version = ST_API_MINOR_VERSION;

/*** API implementation ******************************************************/

/**
 * st_check_api_version:
 * @required_major_version: the required major API version.
 * @minimum_minor_version: the minimum minor API version.
 *
 * Checks if the streamtuner API version matches
 * @required_major_version and @minimum_minor_version.
 *
 * Return value: %TRUE if the requirements are met.
 **/
gboolean
st_check_api_version (unsigned int required_major_version,
		      unsigned int minimum_minor_version)
{
  return st_api_major_version == required_major_version
    && st_api_minor_version >= minimum_minor_version;
}
